@@ -30,7 +30,12 @@ class LoadConf:
         读取服务启动配置信息
         :return: 配置信息节点
         """
-        return self.configuration.__read__(conf_node)
+        res = None
+        try:
+            res = self.configuration.__read__(conf_node)
+        except Exception as e:
+            print('[eqsmart] [read conf]', conf_node, 'not exist', str(e))
+        return res
 
     def load_ext(self, path):
         """
