@@ -3,6 +3,7 @@ import socket
 import sys
 from threading import Thread
 from eqsmart.components.protocol import *
+import traceback
 
 
 def not_c_key(p_dict, p_key):
@@ -71,11 +72,11 @@ class Provider:
                     method = getattr(call_func['func'], data_json['func'])
                     response = method(*tuple(data_json['args']), **data_json['kwargs'])
                 except Exception as e:
-                    print(e)
-                    response['code'] = 'remote_call_error'
-                    response['message'] = str(e)
+                    print(e, traceback.format_exc())
+                    response['code'] = 'remote_func_call_error'
+                    response['message'] = str(e) + str(traceback.format_exc())
                 print('[eqsmart] [provider] 返回给客户端数据:', response)
-                connect.sendall(bytes(json.dumps(response).encode('utf-8')))
+                connect.sendall(bytes(json.dumps(response, default=str).encode('utf-8')))
             except socket.error as e:
                 print(str(e))
                 break
